#include "file_handler.h"

#include <stdio.h>

main()
{
      linked_list* ll = load_list(METRIC_PLUGIN);
    add_metric_plugin(ll, "MetricPluginClass", "MetricPluginName");
    save_list(ll);
    clear_list(ll);

    ll = load_list(METRIC_PLUGIN);
    mp_list* ml = ll->value_list.metric_plugin;
    while(ml)
    {
      fprintf(stderr, "%s:%s\n", ml->metric_definition_class_name, ml->metric_plugin_name);
      ml = ml->next;
    }
    clear_list(ll);

}
